@@ -13,7 +13,7 @@ import aws_cdk.aws_ec2
 import aws_cdk.aws_iam
 import aws_cdk.aws_kms
 import aws_cdk.aws_lambda
-import aws_cdk.cdk
+import aws_cdk.core
 __all__ = []
 
 publication.publish()
